TTVideoEngineSourceRefreshStrategy class

源刷新策略管理类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearGenerateFileKeyCallback() → void
清除 HLS CacheKey 生成回调
clearUrlRefreshCallback() → void
清除 URL 刷新回调
init() Future<void>
初始化源刷新策略
setGenerateFileKeyCallback(GenerateFileKeyCallback callback) → void
设置 HLS CacheKey 生成回调(可选) callback 用于生成 HLS TS 文件的 cacheKey,保证签算变化时 cacheKey 唯一性
setUrlRefreshCallback(TTVideoEngineUrlRefreshCallback callback) → void
设置 URL 刷新回调 callback 客户实现的 URL 刷新回调,用于获取新的播放地址