TTVideoEngineUrlRefreshCallback class abstract

URL 刷新回调接口 - 客户需要实现此接口

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
取消正在进行的刷新操作
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshUrl(TTVideoEngineUrlRequest request) Future
刷新过期的 URL。 可返回 TTVideoEngineUrlResult,或返回包含全部播放地址的 TTVideoEngineMediaSource/Map/List。 当返回全部播放地址时,SDK 会根据 request.url 的 path 匹配出新的 URL。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited