TTVideoEngineUrlResult class
URL 刷新结果类
Constructors
- TTVideoEngineUrlResult({required String url, required int expireTimeInMS})
-
const
-
TTVideoEngineUrlResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- expireTimeInMS → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited