onVideoStreamBitrateChanged property

void Function(TTVideoEngineResolutionType? resolution, int bitrate)? onVideoStreamBitrateChanged
getter/setter pair

Called when the selected video stream bitrate changes.

resolution is null when native does not report a resolution or reports a value that this plugin version does not recognize. bitrate is in bits per second (bps).

Implementation

void Function(TTVideoEngineResolutionType? resolution, int bitrate)?
    onVideoStreamBitrateChanged;